@@ -291,7 +291,12 @@ impl<'a, I: Tokens> Parser<I> {
                 }
 
                 tok!('[') => {
-                    return self.parse_array_lit();
+                    let ctx = Context {
+                        is_direct_child_of_cond: false,
+                        dont_parse_colon_as_type_ann: false,
+                        ..self.ctx()
+                    };
+                    return self.with_ctx(ctx).parse_array_lit();
                 }
 
                 tok!('{') => {
@@ -679,10 +684,10 @@ impl<'a, I: Tokens> Parser<I> {
             }
         }
 
-        let return_type = if !self.ctx().in_cond_expr
+        let return_type = if !(self.ctx().in_cond_expr && self.ctx().is_direct_child_of_cond)
             && self.input.syntax().typescript()
             && is!(self, ':')
-            && !self.ctx().in_case_cond
+            && !self.ctx().dont_parse_colon_as_type_ann
         {
             Some(self.parse_ts_type_or_type_predicate_ann(&tok!(':'))?)
         } else {
@@ -1578,7 +1583,7 @@ impl<'a, I: Tokens> Parser<I> {
     pub(super) fn parse_lit(&mut self) -> PResult<Lit> {
         let start = cur_pos!(self);
 
-        let v = match *cur!(self, true)? {
+        let v = match cur!(self, true)? {
             Word(Word::Null) => {
                 bump!(self);
                 let span = span!(self, start);
@@ -1616,7 +1621,7 @@ impl<'a, I: Tokens> Parser<I> {
                 }),
                 _ => unreachable!(),
             },
-            _ => unreachable!("parse_lit should not be called"),
+            token => unreachable!("parse_lit should not be called for {:?}", token),
         };
         Ok(v)
     }
