@@ -143,7 +143,7 @@ impl<'a, I: Tokens> Parser<I> {
             }
             && (peeked_is!(self, IdentName) || peeked_is!(self, '{') || peeked_is!(self, '['));
         if has_modifier {
-            let _ = self.parse_ts_modifier(&["public", "protected", "private", "readonly"]);
+            let _ = self.parse_ts_modifier(&["public", "protected", "private", "readonly"], false);
         }
 
         return Ok(has_modifier);
@@ -321,8 +321,8 @@ impl<'a, I: Tokens> Parser<I> {
             let accessibility = self.parse_access_modifier()?;
             (
                 accessibility,
-                self.parse_ts_modifier(&["override"])?.is_some(),
-                self.parse_ts_modifier(&["readonly"])?.is_some(),
+                self.parse_ts_modifier(&["override"], false)?.is_some(),
+                self.parse_ts_modifier(&["readonly"], false)?.is_some(),
             )
         } else {
             (None, false, false)
